<?php

class PremisePostAffiliatePro_Admin_Boxes extends Premise_Admin_Boxes {

	function __construct() {
		$menu_options = array(
			'submenu' => array(
				'parent_slug' => 'premise-member',
				'page_title' => 'Post Affiliate Pro Settings',
				'menu_title' => 'Post Affiliate Pro',
				'capability' => 'manage_options',
			)
		);

		$default_settings = array(
			'enabled' => 0,
			'url' => 'www.yoursite.com/pap_directory/',
			'accountID' => 'default1',
			'product' => '',
			'edata_1' => '',
			'edata_2' => '',
			'edata_3' => '',
			'edata_4' => ''
		);

		$this->create('premise-postaffiliatepro', $menu_options, array(), 'premise-postaffiliatepro-settings', $default_settings);

		add_action('admin_enqueue_scripts', array($this, 'enqueue_admin_css'));
	}

	function enqueue_admin_css() {
		$screen = get_current_screen();

		if (! $screen || 'member-access_page_premise-postaffiliatepro' != $screen->id)
			return;

		wp_enqueue_style( 'premise-admin', PREMISE_RESOURCES_URL . 'premise-admin.css', array( 'thickbox' ), PREMISE_VERSION );
	}

	function metaboxes() {
		add_meta_box('premise-postaffiliatepro-settings', 'Post Affiliate Pro Settings', array($this, 'settings'), $this->pagehook, 'main');
	}

	function settings() {
		$optional_variables = array(
			'customer_name' => __('Customer Name'),
			'customer_email' => __('Customer Email'),
			'customer_username' => __('Customer Username');
			'site_name' => __('Site Name'),
		);

		$optional_variables = apply_filters('premise_postaffiliatepro_optional_variables', $optional_variables);
		
		?>

		<p>
			<label for="<?php echo $this->get_field_id('url'); ?>"><?php _e('Post Affiliate Pro URL'); ?></label><br />
			<input type="text" name="<?php echo $this->get_field_name('url'); ?>" id="<?php echo $this->get_field_id('url'); ?>" value="<?php echo $this->get_field_value('url'); ?>">
		</p>

		<p>
			<label for="<?php echo $this->get_field_id('enabled'); ?>"><?php _e('Enable'); ?> <input type="checkbox" name="<?php echo $this->get_field_name('enabled'); ?>" id="<?php echo $this->get_field_id('enabled'); ?>" value="1" <?php checked($this->get_field_value('enabled'), 1); ?>>
			</label>
		</p>

		<p>
			<label for="<?php echo $this->get_field_id('accountID'); ?>"><?php _e('Account ID (for Network licenses)'); ?></label><br>
			<input type="text" name="<?php echo $this->get_field_name('accountID'); ?>" id="<?php echo $this->get_field_id('accountID'); ?>" value="<?php echo $this->get_field_value('accountID'); ?>">
		</p>
		
		<p>
			<label for="<?php echo $this->get_field_id('product'); ?>"><?php _e('Product ID or Name'); ?></label><br>
			<select id="<?php echo $this->get_field_id('product'); ?>" name="<?php echo $this->get_field_name('product'); ?>">
				<option value="product_id" <?php echo selected($this->get_field_value('product'); ?>><?php __('Product ID'); ?></option>
				<option value="product_name" <?php echo selected($this->get_field_value('product'); ?>><?php __('Product Name'); ?></option>
			</select>
    </p>

		<?php for ($i = 1; $i <= 4; $i++) { ?>
			<p>
				<label for="<?php echo $this->get_field_id('edata_' . $i); ?>"><?php printf(__('Extra data %d'), $i); ?></label>
				<select id="<?php echo $this->get_field_id('edata_' . $i); ?>" name="<?php echo $this->get_field_name('edata_' . $i); ?>">
					<option value=""><?php _e('None'); ?></option>

					<?php
          foreach ($optional_variables as $k => $v) {
						echo '<option value="'.$k.'" '.selected($this->get_field_value('edata_' . $i), $k).'>'.$v.'</option>';
					}
          ?>
				</select>
			</p>
		<?php
    }
	}
}

new PremisePostAffiliatePro_Admin_Boxes;
